
# CLI Commands CGSE

The CGSE comes with a suite of CLI commands to start and stop services, get 
status reports and check the installation. It's actually a suite of `cgse` 
sub-commands that is extendable by external packages. This section will 
describe the commands that are available from the `cgse` packages.

## The `cgse` command

When you run the `cgse` command without arguments, you will see something 
like this.
![cli-cgse.png](../images/cli-cgse.png)
